Module cte

Module cte 

Common table expressions (WITH name AS (...)) for SQLite.

Make one with into_cte and add it to a query with QueryBuilder::with.

Traits

CTEDefinition
A common table expression that can be passed to QueryBuilder::with.

Type Aliases

CTEView
A named SELECT used as a common table expression.