Module common

Module common 

SQLite schema marker, the Number type, and the Join re-export.

Structs

Join
The JOIN keyword of a join clause, such as NATURAL LEFT OUTER JOIN.

Enums

JoinType
The kind of a JOIN.
Number
A number that is either an integer or a floating-point value.
SQLiteSchemaType
The SQLite dialect marker for schema items.