SQLiteTransactionType

Type Alias SQLiteTransactionType 

pub type SQLiteTransactionType = TransactionConfig;
Backwards-compatible name for TransactionConfig.

Aliased Type

pub enum SQLiteTransactionType {
    Deferred,
    Immediate,
    Exclusive,
}

Variants



Deferred

Takes no lock until the first read or write. The default.



Immediate

Starts a write transaction at once, so other connections cannot start writing.



Exclusive

Like Immediate; in rollback-journal mode it also blocks other connections from reading.