Module traits

Module traits 

SQLite traits for tables, columns, custom column types and row decoding.

Traits

DrizzleRowByIndex
A driver row whose columns can be read by position.
DrizzleRowByName
A driver row whose columns can also be read by name.
DrizzleSQLiteColumn
A Rust type that can be stored in a SQLite column.
FromSQLiteValue
Decodes a Rust value from a SQLite value.
SQLiteAffinity
The SQLite type affinity of a SQL type marker such as Integer or Text.
SQLiteColumn
A column of a SQLite table. Implemented by #[SQLiteTable].
SQLiteTable
A SQLite table. Implemented by #[SQLiteTable].