DrizzleRowByName

Trait DrizzleRowByName 

pub trait DrizzleRowByName: DrizzleRowByIndex {
    // Required method
    fn get_column_by_name<T: FromSQLiteValue>(
        &self,
        name: &str,
    ) -> Result<T, DrizzleError>;
}
Optional row capability for name-based extraction.

Required Methods

fn get_column_by_name<T: FromSQLiteValue>( &self, name: &str, ) -> Result<T, DrizzleError>

Get a column value by name.

Errors

Returns DrizzleError if the name does not resolve to a column or the column value cannot be converted to T.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors