Module values

Module values 

SQLite value types and conversions

This module contains the core SQLiteValue type and all its conversions.

Re-exports

pub use owned::*;

Modules

owned
Owned SQLite value type and implementations

Enums

SQLiteInsertValue
Represents a value for INSERT operations that can be omitted, null, or a SQL expression
SQLiteUpdateValue
Represents a value for UPDATE operations that can be skipped, null, or a SQL expression.
SQLiteValue
Represents a SQLite value
SQLiteValueRef
Borrowed view of a SQLite value.