Module traits

Module traits 

SQLite-specific traits for tables, columns, and values

Traits

DrizzleRowByIndex
Row capability for index-based extraction.
DrizzleRowByName
Optional row capability for name-based extraction.
DrizzleSQLiteColumn
Marker trait for custom Rust types that map to a SQLite column.
FromSQLiteValue
Trait for types that can be converted from SQLite values.
SQLiteColumn
SQLiteTable