SQLite value types and conversions
This module contains the core SQLiteValue type and all its conversions.
Re-exports
pub use owned::*;
Modules
- owned
- Owned
SQLitevalue type and implementations
Enums
- SQLite
Insert Value - Represents a value for INSERT operations that can be omitted, null, or a SQL expression
- SQLite
Update Value - Represents a value for UPDATE operations that can be skipped, null, or a SQL expression.
- SQLite
Value - Represents a
SQLitevalue - SQLite
Value Ref - Borrowed view of a
SQLitevalue.